## fallible features

These additional features have been included in this release of fallible:


- [84621 - [WIP] Templating overhaul, implement Data Tagging](https://github.com/ansible/ansible/pull/84621)
